use crate::client::{JiraCommand, JiraRequestType};
use crate::entities::transitions::{IssueTransitionUpdatePayload, IssueTransitionUpdatePayloadId};

#[derive(Debug)]
pub struct IssueTransitionsUpdateCommand {
    pub issue_key: String,
    pub transition: IssueTransitionUpdatePayload,
}

impl IssueTransitionsUpdateCommand {
    pub fn new(issue_key: &str, transition_id: &str) -> Self {
        Self {
            issue_key: issue_key.to_string(),
            transition: IssueTransitionUpdatePayload {
                transition: IssueTransitionUpdatePayloadId {
                    id: transition_id.to_string(),
                },
            },
        }
    }
}

impl JiraCommand for IssueTransitionsUpdateCommand {
    type TResponse = ();
    type TPayload = IssueTransitionUpdatePayload;
    const REQUEST_TYPE: JiraRequestType = JiraRequestType::Create;

    fn endpoint(&self) -> String {
        format!("/rest/api/3/issue/{}/transitions", self.issue_key)
    }

    fn request_body(&self) -> Option<&Self::TPayload> {
        Some(&self.transition)
    }

    fn query_params(&self) -> Option<Vec<(String, String)>> {
        None
    }
}
