use serde::{Deserialize, Serialize};

#[derive(Debug, Clone, Deserialize)]
pub struct IssueCreateResponse {
    pub key: String,
}

#[derive(Debug, Clone, Serialize)]
pub struct IssueCreateRequest {
    pub fields: IssueFields,
    pub update: Option<IssueUpdate>,
}

#[derive(Debug, Clone, Serialize)]
pub struct IssueUpdate {
    #[serde(skip_serializing_if = "Option::is_none")]
    pub parent: Option<Vec<ParentUpdate>>,
}

#[derive(Debug, Clone, Serialize)]
pub struct ParentUpdate {
    pub add: Parent,
}

#[derive(Debug, Clone, Serialize)]
pub struct Parent {
    pub key: String,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct IssueFields {
    pub project: Project,
    pub summary: String,
    pub description: String,
    #[serde(rename = "issuetype")]
    pub issue_type: IssueType,
    #[serde(skip_serializing_if = "Option::is_none")]
    pub assignee: Option<Assignee>,
    #[serde(skip_serializing_if = "Option::is_none")]
    pub status: Option<Status>,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct Assignee {
    pub id: String,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct Project {
    pub key: String,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct IssueType {
    pub name: String,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct Status {
    pub name: String,
}
